@@ -1,7 +1,5 @@
 #include "curl_setup.h"
-
 #include <curl/curl.h>
-
 #include "impersonate.h"
 
 const struct impersonate_opts impersonations[] = {
@@ -54,6 +52,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "chrome101",
@@ -104,6 +103,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "chrome104",
@@ -154,6 +154,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "chrome107",
@@ -204,6 +205,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "chrome110",
@@ -255,6 +257,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "chrome116",
@@ -306,6 +309,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "chrome119",
@@ -358,6 +362,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "chrome120",
@@ -410,6 +415,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "chrome123",
@@ -462,6 +468,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "chrome124",
@@ -516,6 +523,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "chrome131",
@@ -570,6 +578,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "chrome131_android",
@@ -624,6 +633,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "chrome133a",
@@ -678,6 +688,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "chrome136",
@@ -732,6 +743,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "chrome142",
@@ -786,6 +798,66 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
+  },
+  {
+    .target = "chrome145",
+    .alias = "chrome145",
+    .httpversion = CURL_HTTP_VERSION_2_0,
+    .ssl_version = CURL_SSLVERSION_TLSv1_2 | CURL_SSLVERSION_MAX_DEFAULT,
+    .ciphers =
+      "TLS_AES_128_GCM_SHA256:"
+      "TLS_AES_256_GCM_SHA384:"
+      "TLS_CHACHA20_POLY1305_SHA256:"
+      "ECDHE-ECDSA-AES128-GCM-SHA256:"
+      "ECDHE-RSA-AES128-GCM-SHA256:"
+      "ECDHE-ECDSA-AES256-GCM-SHA384:"
+      "ECDHE-RSA-AES256-GCM-SHA384:"
+      "ECDHE-ECDSA-CHACHA20-POLY1305:"
+      "ECDHE-RSA-CHACHA20-POLY1305:"
+      "ECDHE-RSA-AES128-SHA:"
+      "ECDHE-RSA-AES256-SHA:"
+      "AES128-GCM-SHA256:"
+      "AES256-GCM-SHA384:"
+      "AES128-SHA:"
+      "AES256-SHA",
+    .curves = "X25519MLKEM768:X25519:P-256:P-384",
+    .npn = false,
+    .alpn = true,
+    .alps = true,
+    .tls_permute_extensions = true,
+    .tls_session_ticket = true,
+    .cert_compression = "brotli",
+    .http_headers = {
+      "sec-ch-ua: \"Not:A-Brand\";v=\"99\", \"Google Chrome\";v=\"145\", \"Chromium\";v=\"145\"",
+      "sec-ch-ua-mobile: ?0",
+      "sec-ch-ua-platform: \"macOS\"",
+      "Upgrade-Insecure-Requests: 1",
+      "User-Agent: Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/145.0.0.0 Safari/537.36",
+      "Accept: text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7",
+      "Sec-Fetch-Site: none",
+      "Sec-Fetch-Mode: navigate",
+      "Sec-Fetch-User: ?1",
+      "Sec-Fetch-Dest: document",
+      "Accept-Encoding: gzip, deflate, br, zstd",
+      "Accept-Language: en-US,en;q=0.9",
+      "Priority: u=0, i"
+    },
+    .http2_settings = "1:65536;2:0;4:6291456;6:262144",
+    .http2_window_update = 15663105,
+    .http2_stream_weight = 256,
+    .http2_stream_exclusive = 1,
+    .http3_settings = "1:65536;6:262144;7:100;51:1;GREASE",
+    .http3_pseudo_headers_order = "masp",
+    .quic_transport_parameters = "1:30000;3:1472;4:15728640;5:6291456;6:6291456;7:6291456;8:100;9:103;15:;17:1@1,GREASE;32:65536;12583:AUTO;18258:1;GREASE",
+    .http3_tls_extension_order = "0-10-13-16-27-43-45-51-57-17613-65037",
+    .ech = "true",
+    .tls_extension_order = NULL,
+    .tls_use_new_alps_codepoint = true,
+    .tls_signed_cert_timestamps = true,
+    .tls_grease = true,
+    .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "chrome99",
@@ -836,6 +908,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "chrome99_android",
@@ -886,6 +959,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "edge101",
@@ -936,6 +1010,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "edge99",
@@ -986,6 +1061,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "firefox133",
@@ -1050,6 +1126,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = false,
     .tls_key_shares_limit = 3,
     .split_cookies = true,
+    .form_boundary = "firefox",
   },
   {
     .target = "firefox135",
@@ -1115,6 +1192,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_key_shares_limit = 3,
     .split_cookies = true,
+    .form_boundary = "firefox",
   },
   {
     .target = "firefox144",
@@ -1181,6 +1259,78 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_key_shares_limit = 3,
     .split_cookies = true,
+    .form_boundary = "firefox",
+  },
+  {
+    .target = "firefox147",
+    .alias = "firefox147",
+    .httpversion = CURL_HTTP_VERSION_2_0,
+    .ssl_version = CURL_SSLVERSION_TLSv1_2 | CURL_SSLVERSION_MAX_DEFAULT,
+    .ciphers =
+      "TLS_AES_128_GCM_SHA256:"
+      "TLS_CHACHA20_POLY1305_SHA256:"
+      "TLS_AES_256_GCM_SHA384:"
+      "TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256:"
+      "TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256:"
+      "TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305_SHA256:"
+      "TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305_SHA256:"
+      "TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384:"
+      "TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384:"
+      "TLS_ECDHE_ECDSA_WITH_AES_256_CBC_SHA:"
+      "TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA:"
+      "TLS_ECDHE_RSA_WITH_AES_128_CBC_SHA:"
+      "TLS_ECDHE_RSA_WITH_AES_256_CBC_SHA:"
+      "TLS_RSA_WITH_AES_128_GCM_SHA256:"
+      "TLS_RSA_WITH_AES_256_GCM_SHA384:"
+      "TLS_RSA_WITH_AES_128_CBC_SHA:"
+      "TLS_RSA_WITH_AES_256_CBC_SHA",
+    .http_headers = {
+      "User-Agent: Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:135.0) Gecko/20100101 Firefox/147.0",
+      "Accept: text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
+      "Accept-Language: en-US,en;q=0.9",
+      "Accept-Encoding: gzip, deflate, br, zstd",
+      "Upgrade-Insecure-Requests: 1",
+      "Sec-Fetch-Dest: document",
+      "Sec-Fetch-Mode: navigate",
+      "Sec-Fetch-Site: none",
+      "Sec-Fetch-User: ?1",
+      "Priority: u=0, i",
+      "Te: trailers"
+    },
+    .curves = "X25519MLKEM768:X25519:P-256:P-384:P-521:ffdhe2048:ffdhe3072",
+    .sig_hash_algs =
+      "ecdsa_secp256r1_sha256:"
+      "ecdsa_secp384r1_sha384:"
+      "ecdsa_secp521r1_sha512:"
+      "rsa_pss_rsae_sha256:"
+      "rsa_pss_rsae_sha384:"
+      "rsa_pss_rsae_sha512:"
+      "rsa_pkcs1_sha256:"
+      "rsa_pkcs1_sha384:"
+      "rsa_pkcs1_sha512:"
+      "ecdsa_sha1:"
+      "rsa_pkcs1_sha1",
+    .alpn = true,
+    .http2_settings = "1:65536;2:0;4:131072;5:16384",
+    .http2_window_update = 12517377,
+    .http2_pseudo_headers_order = "mpas",
+    .http2_stream_exclusive = 0,
+    .http2_stream_weight = 42,
+    .http3_settings = "1:65536;7:20;727725890:0;16765559:1;51:1;8:1",
+    .http3_pseudo_headers_order = "msap",
+    .quic_transport_parameters = "1:30000;4:25165824;5:12582912;6:1048576;7:1048576;8:100;9:100;11:20;14:8;15:AUTO;17:1@GREASE,1;GREASE;32:65535",
+    .http3_tls_extension_order = "28-51-27-13-34-10-45-16-65281-23-5-0-43-57-65037",
+    .cert_compression = "zlib,brotli,zstd",
+    .ech = "true",
+    .tls_session_ticket = true,
+    .tls_extension_order = "0-23-65281-10-11-35-16-5-34-18-51-43-13-45-28-27-65037",
+    .tls_delegated_credentials = "ecdsa_secp256r1_sha256:ecdsa_secp384r1_sha384:ecdsa_secp521r1_sha512:ecdsa_sha1",
+    .tls_record_size_limit = 4001,
+    .tls_grease = false,
+    .tls_signed_cert_timestamps = true,
+    .tls_key_shares_limit = 3,
+    .split_cookies = true,
+    .form_boundary = "firefox",
   },
   {
     .target = "okhttp4_android",
@@ -1310,6 +1460,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "safari155",
@@ -1371,6 +1522,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "safari170",
@@ -1435,6 +1587,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "safari172_ios",
@@ -1499,6 +1652,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "safari180",
@@ -1563,6 +1717,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "safari180_ios",
@@ -1627,6 +1782,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "safari184",
@@ -1691,6 +1847,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "safari184_ios",
@@ -1755,6 +1912,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "safari260",
@@ -1818,6 +1976,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "safari2601",
@@ -1881,6 +2040,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "safari260_ios",
@@ -1944,6 +2104,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_grease = true,
     .split_cookies = true,
+    .form_boundary = "webkit",
   },
   {
     .target = "tor145",  // tor 14.5, based on firefox 128
@@ -2008,6 +2169,7 @@ const struct impersonate_opts impersonations[] = {
     .tls_signed_cert_timestamps = true,
     .tls_key_shares_limit = 2,
     .split_cookies = true,
+    .form_boundary = "firefox",
   }
 };
 
