@@ -1247,6 +1247,7 @@ enum dupstring {
   STRING_SSL_ISSUERCERT, /* issuer cert file to check certificate */
   STRING_SERVICE_NAME,    /* Service name */
   STRING_IMPERSONATE,     /* curl-impersonate */
+  STRING_FORM_BOUNDARY,   /* CURLOPT_FORM_BOUNDARY */
 #ifndef CURL_DISABLE_PROXY
   STRING_CERT_PROXY,      /* client certificate filename */
   STRING_CERT_TYPE_PROXY, /* format for certificate (default: PEM)*/
@@ -1361,6 +1362,9 @@ enum dupstring {
   STRING_HTTP2_PSEUDO_HEADERS_ORDER,
   STRING_HTTP2_SETTINGS,
   STRING_HTTP2_STREAMS,
+  STRING_HTTP3_PSEUDO_HEADERS_ORDER,
+  STRING_HTTP3_SETTINGS,
+  STRING_QUIC_TRANSPORT_PARAMETERS,
   STRING_TLS_EXTENSION_ORDER,
   STRING_TLS_DELEGATED_CREDENTIALS,
   STRING_SSL_SIGNATURE_ALGORITHMS, /* CURLOPT_SSL_SIGNATURE_ALGORITHMS */
