@@ -722,8 +722,7 @@ CURLcode get_args(struct OperationConfig *config, const size_t i)
   env_target = curl_getenv("CURL_IMPERSONATE");
 
   /* Check if we have a user agent, do not override impersonate value */
-  if(!result && !config->useragent &&
-     !config->impersonate && !env_target) {
+  if(!result && !config->useragent && !config->impersonate && !env_target) {
     config->useragent = my_useragent();
     if(!config->useragent) {
       errorf(config->global, "out of memory");
